summaryrefslogtreecommitdiffstats
path: root/src/kernel/qeventloop.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/kernel/qeventloop.cpp')
-rw-r--r--src/kernel/qeventloop.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/kernel/qeventloop.cpp b/src/kernel/qeventloop.cpp
index 480cbf54..2dab316d 100644
--- a/src/kernel/qeventloop.cpp
+++ b/src/kernel/qeventloop.cpp
@@ -139,7 +139,7 @@ TQEventLoop::~TQEventLoop()
TQTimer with 0 timeout. More advanced idle processing schemes can
be achieved using processEvents().
- \sa TQApplication::tquit(), exit(), processEvents()
+ \sa TQApplication::quit(), exit(), processEvents()
*/
int TQEventLoop::exec()
{
@@ -149,12 +149,12 @@ int TQEventLoop::exec()
// cleanup
d->looplevel = 0;
- d->tquitnow = FALSE;
+ d->quitnow = FALSE;
d->exitloop = FALSE;
d->shortcut = FALSE;
- // don't reset tquitcode!
+ // don't reset quitcode!
- return d->tquitcode;
+ return d->quitcode;
}
/*! \fn void TQEventLoop::exit( int retcode = 0 )
@@ -171,14 +171,14 @@ int TQEventLoop::exec()
function \e does return to the caller -- it is event processing that
stops.
- \sa TQApplication::tquit(), exec()
+ \sa TQApplication::quit(), exec()
*/
void TQEventLoop::exit( int retcode )
{
- if ( d->tquitnow ) // preserve existing tquitcode
+ if ( d->quitnow ) // preserve existing quitcode
return;
- d->tquitcode = retcode;
- d->tquitnow = TRUE;
+ d->quitcode = retcode;
+ d->quitnow = TRUE;
d->exitloop = TRUE;
d->shortcut = TRUE;
}
@@ -201,13 +201,13 @@ int TQEventLoop::enterLoop()
processEvents( AllEvents | WaitForMore );
d->looplevel--;
// restore the exitloop state, but if tquitnow is TRUE, we need to keep
// exitloop set so that all other event loops drop out.
- d->exitloop = old_exitloop || d->tquitnow;
- d->shortcut = d->tquitnow;
+ d->exitloop = old_exitloop || d->quitnow;
+ d->shortcut = d->quitnow;
if ( d->looplevel < 1 ) {
- d->tquitnow = FALSE;
+ d->quitnow = FALSE;
d->exitloop = FALSE;
d->shortcut = FALSE;
emit qApp->aboutToQuit();
@@ -258,7 +258,7 @@ void TQEventLoop::processEvents( ProcessEventsFlags flags, int maxTime )
{
TQTime start = TQTime::currentTime();
TQTime now;
- while ( ! d->tquitnow && processEvents( flags & ~WaitForMore ) ) {
+ while ( ! d->quitnow && processEvents( flags & ~WaitForMore ) ) {
now = TQTime::currentTime();
if ( start.msecsTo( now ) > maxTime )
break;
@@ -201,13 +201,13 @@ int TQEventLoop::enterLoop()
processEvents( AllEvents | WaitForMore );
d->looplevel--;
- // restore the exitloop state, but if tquitnow is TRUE, we need to keep
+ // restore the exitloop state, but if quitnow is TRUE, we need to keep
// exitloop set so that all other event loops drop out.